@@ -13,14 +13,14 @@
 namespace OCA\Mail\Db;
 
 use OCP\AppFramework\Db\Mapper;
-use OCP\IDb;
+use OCP\IDBConnection;
 
 class AliasMapper extends Mapper {
 
 	/**
-	 * @param IDb $db
+	 * @param IDBConnection $db
 	 */
-	public function __construct(IDb $db) {
+	public function __construct(IDBConnection $db) {
 		parent::__construct($db, 'mail_aliases');
 	}
 
